/**
 *  Vue BarajaJS
 *  A plugin for spreading items in a card-like fashion.
 *
 *  Copyright 2021, Marc S. Brooks (https://mbrooks.info)
 *  Licensed under the MIT license:
 *  http://www.opensource.org/licenses/mit-license.php
 */

'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _vue = require('vue');

var _barajaJs = require('baraja-js');

var _barajaJs2 = _interopRequireDefault(_barajaJs);

require('baraja-js/dist/baraja.min.css');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * Provides Vue Component wrapper.
 */
exports.default = {
  setup: function setup(props) {
    var elRef = (0, _vue.ref)(null);

    return { elRef: elRef };
  },
  mounted: function mounted() {
    this.baraja = new _barajaJs2.default(this.$el, this.options);
  },
  data: function data() {
    return {
      baraja: null
    };
  },


  watch: {
    fan: function fan(newVal, oldVal) {
      if (!Object.is(newVal, oldVal)) {
        this.baraja.fan(newVal);
      }
    },
    add: function add(newVal, oldVal) {
      if (newVal !== oldVal) {
        this.baraja.add(newVal);
      }
    },
    close: function close(newVal, oldVal) {
      if (newVal !== oldVal) {
        this.baraja.close();
      }
    },
    last: function last(newVal, oldVal) {
      if (newVal !== oldVal) {
        this.baraja.last();
      }
    },
    next: function next(newVal, oldVal) {
      if (newVal !== oldVal) {
        this.baraja.next();
      }
    }
  },

  props: {
    id: {
      default: 'baraja-js',
      type: String
    },
    options: {
      default: function _default() {
        return {};
      },
      type: Object
    },
    fan: {
      default: function _default() {
        return {};
      },
      type: Object
    },
    add: {
      default: '',
      type: String
    },
    close: {
      default: false,
      type: Boolean
    },
    last: {
      default: false,
      type: Boolean
    },
    next: {
      default: false,
      type: Boolean
    }
  },

  template: '\n    <ul v-bind:id="id" class="baraja-container" ref="wrapper">\n      <slot :child="this.$slots.default" />\n    </ul>\n  '
};
//# sourceMappingURL=vue-baraja.js.map